@@ -1,4 +1,4 @@
-utils::globalVariables(names=c("fum","element_blank","value","ratio","aes","variable","geom_bar","geom_text","position","guides","labs","theme","element_text","scale_y_continuous","position_dodge","ylim","guide_legend","scale_fill_discrete", "aes_string", "geom_boxplot","stat_summary", "theme_bw", "freq", "geom_vline", "geom_density", "margin", "scale_colour_continuous",'Var1','label','coord_flip','ylab','xlab','geom_label','unit','Population','Gain','Score.Point','geom_line','geom_point','xlim','geom_segment','Lift', 'Freq', 'sum_pos', 'likelih','.','one_of','grp_mean', 'mean_target',"'colorRampPalette","head","tail","rbeta","p_10","p_90","sd" ,"std_dev","variation_coef","iqr","type"), package = "funModeling", add = F)
+utils::globalVariables(names=c("fum","element_blank","value","ratio","aes","variable","geom_bar","geom_text","position","guides","labs","theme","element_text","scale_y_continuous","position_dodge","ylim","guide_legend","scale_fill_discrete", "aes_string", "geom_boxplot","stat_summary", "theme_bw", "freq", "geom_vline", "geom_density", "margin", "scale_colour_continuous",'Var1','label','coord_flip','ylab','xlab','geom_label','unit','Population','Gain','Score.Point','geom_line','geom_point','xlim','geom_segment','Lift', 'Freq', 'sum_pos', 'likelih','.','one_of','grp_mean', 'mean_target',"'colorRampPalette","head","tail","rbeta","p_10","p_90","sd" ,"std_dev","variation_coef","iqr","type","gr","discretize_bins", "cuts"), package = "funModeling", add = F)
 
 
 #' @importFrom grDevices dev.off jpeg rainbow
@@ -6,7 +6,7 @@ utils::globalVariables(names=c("fum","element_blank","value","ratio","aes","vari
 #' @importFrom stats predict frequency
 #' @importFrom pander pandoc.table
 #' @importFrom  Hmisc cut2
-#' @import  ggplot2
+#' @import ggplot2
 #' @import dplyr
 #' @importFrom reshape2 dcast melt
 #' @importFrom utils packageVersion
@@ -20,6 +20,7 @@ utils::globalVariables(names=c("fum","element_blank","value","ratio","aes","vari
 #' @importFrom stats kmeans rbeta hclust cutree dist IQR na.omit sd mad median
 #' @importFrom utils head tail
 #' @importFrom moments skewness kurtosis
+#' @importFrom entropy entropy
 
 #' @title Cross-plotting input variable vs. target variable
 #' @description The cross_plot shows how the input variable is correlated with the target variable, getting the likelihood rates for each input's bin/bucket .
@@ -75,7 +76,7 @@ cross_plot <- function(data, str_input, str_target, path_out, auto_binning, plot
 
 
 
-cross_plot_logic<-function(data, str_input, str_target, path_out, auto_binning, plot_type)
+cross_plot_logic <- function(data, str_input, str_target, path_out, auto_binning, plot_type)
 {
 	# data=heart_disease; str_input="max_heart_rate"; str_target="has_heart_disease"; auto_binning=T
 	  check_target_existence(data, str_target=str_target)
@@ -140,7 +141,7 @@ cross_plot_logic<-function(data, str_input, str_target, path_out, auto_binning,
 	  ## Generating Id indicator for odd/even calculus
 	  rownames(dataGrafPrep) = 1:nrow(dataGrafPrep)
 
-	  ## Computing if the row is odd/even
+	  # Computing if the row is odd/even
 	  dataGrafPrep$fum=as.numeric(as.numeric(rownames(dataGrafPrep)) %% 2 == 0)
 
 	  ## Computing middle position in each sub bar
