@@ -1,10 +1,10 @@
 #' @title Reduce cardinality in categorical variable by automatic grouping
-#' @description Reduce the cardinality of an input variable based on a target -binary by now- variable based on attribitues of accuracy and representativity, for both input and target variable. It uses a cluster model to create the new groups. Full documentation can be found at: <http://http://livebook.datascienceheroes.com/data_preparation/high_cardinality_predictive_modeling.html/>
+#' @description Reduce the cardinality of an input variable based on a target -binary by now- variable based on attribitues of accuracy and representativity, for both input and target variable. It uses a cluster model to create the new groups. Full documentation can be found at: \url{https://livebook.datascienceheroes.com/data-preparation.html#high_cardinality_predictive_modeling}
 #' @param data data frame source
 #' @param input categorical variable indicating
 #' @param target string of the variable to optimize the re-grouping
 #' @param n_groups number of groups for the new category based on str_input, normally between 3 and 10.
-#' @param model is the clustering model used to create the grouping, supported models: "kmeans" (default) or hclust.
+#' @param model is the clustering model used to create the grouping, supported models: "kmeans" (default) or "hclust" (hierarchical clustering).
 #' @param seed optional, random number used internally for the k-means, changing this value will change the model
 #' @examples
 #' \dontrun{
@@ -27,10 +27,12 @@ auto_grouping <- function(data, input, target, n_groups, model="kmeans", seed=99
 		fit_cluster=kmeans(scale(data.frame(d)), n_groups)
 		# Checking results: it_cluster$centers;fit_cluster$size
 		cluster_vec=fit_cluster$cluster
-		} else {
+		} else if(model=="hclust"){
 			# hclust
 		fit_cluster=hclust(dist(scale(data.frame(d))))
 		cluster_vec=cutree(fit_cluster, k=n_groups)
+	} else {
+		stop("Parameter 'model' can be 'kmeans' or 'hclust'")
 	}
 
 
@@ -49,3 +51,16 @@ auto_grouping <- function(data, input, target, n_groups, model="kmeans", seed=99
 
 	return(l_res)
 }
+
+#' @title Transform a variable into the [0-1] range
+#' @description Range a variable into [0-1], assigning 0 to the min and 1 to the max of the input variable. All NA values will be removed.
+#' @param var numeric input vector
+#' @examples
+#' range01(mtcars$cyl)
+#' @return vector with the values scaled into the 0 to 1 range
+#' @export
+range01 <- function(var)
+{
+	return((var-min(var, na.rm=T))/(max(var, na.rm=T)-min(var, na.rm=T)))
+}
+
